@@ -5,8 +5,9 @@ Pydantic models for application settings, loaded from .env and CLI args.
 
 from __future__ import annotations
 
+import os
 from pathlib import Path
-from typing import cast
+from typing import Any, cast
 
 from pydantic_settings import BaseSettings, SettingsConfigDict
 
@@ -47,8 +48,18 @@ class AppSettings(BaseSettings):
         env_file=".env",
         env_file_encoding="utf-8",
         extra="ignore",
+        # Add this to handle both SPEX_ prefix and direct env vars
+        case_sensitive=False,
     )
 
+    def __init__(self, **kwargs: Any) -> None:
+        """Custom init to handle environment variable loading."""
+        super().__init__(**kwargs)
+        # If supabase_anon_key is still None, try loading without prefix
+        if self.supabase_anon_key is None:
+            # Try loading directly from environment
+            self.supabase_anon_key = os.getenv("SUPABASE_ANON_KEY")
+
     def get_api_key(self) -> str:
         """Returns the API key for the currently configured provider."""
         key = getattr(self, f"{self.provider}_api_key", None)
